@@ -15,13 +15,13 @@ class ConstrainedFrontend(Frontend):  # pylint:disable=abstract-method
         self._finalized = False
 
     def _blank_copy(self, c):
-        super(ConstrainedFrontend, self)._blank_copy(c)
+        super()._blank_copy(c)
         c.constraints = []
         c.variables = set()
         c._finalized = False
 
     def _copy(self, c):
-        super(ConstrainedFrontend, self)._copy(c)
+        super()._copy(c)
         c.constraints = list(self.constraints)
         c.variables = set(self.variables)
 
@@ -65,7 +65,7 @@ class ConstrainedFrontend(Frontend):  # pylint:disable=abstract-method
         if common_ancestor is None:
             merged = self.blank_copy()
             options = []
-            for s,v in zip([self] + others, merge_conditions):
+            for s, v in zip([self] + others, merge_conditions):
                 options.append(And(*([v] + s.constraints)))
             merged.add([Or(*options)])
         else:
@@ -77,7 +77,7 @@ class ConstrainedFrontend(Frontend):  # pylint:disable=abstract-method
     def combine(self, others):
         combined = self.blank_copy()
 
-        combined.add(self.constraints)    # pylint:disable=E1101
+        combined.add(self.constraints)  # pylint:disable=E1101
         for o in others:
             combined.add(o.constraints)
         return combined
@@ -104,17 +104,19 @@ class ConstrainedFrontend(Frontend):  # pylint:disable=abstract-method
         return constraints
 
     def simplify(self):
-        to_simplify = [ c for c in self.constraints if not any(
-            isinstance(a, SimplificationAvoidanceAnnotation) for a in c.annotations
-        ) ]
-        no_simplify = [ c for c in self.constraints if any(
-            isinstance(a, SimplificationAvoidanceAnnotation) for a in c.annotations
-        ) ]
+        to_simplify = [
+            c
+            for c in self.constraints
+            if not any(isinstance(a, SimplificationAvoidanceAnnotation) for a in c.annotations)
+        ]
+        no_simplify = [
+            c for c in self.constraints if any(isinstance(a, SimplificationAvoidanceAnnotation) for a in c.annotations)
+        ]
 
         if len(to_simplify) == 0:
             return self.constraints
 
-        simplified = simplify(And(*to_simplify)).split(['And']) #pylint:disable=no-member
+        simplified = simplify(And(*to_simplify)).split(["And"])  # pylint:disable=no-member
         self.constraints = no_simplify + simplified
         return self.constraints
 
@@ -134,10 +136,10 @@ class ConstrainedFrontend(Frontend):  # pylint:disable=abstract-method
     def eval(self, e, n, extra_constraints=(), exact=None):
         raise NotImplementedError("eval() is not implemented")
 
-    def min(self, e, extra_constraints=(), exact=None):
+    def min(self, e, extra_constraints=(), signed=False, exact=None):
         raise NotImplementedError("min() is not implemented")
 
-    def max(self, e, extra_constraints=(), exact=None):
+    def max(self, e, extra_constraints=(), signed=False, exact=None):
         raise NotImplementedError("max() is not implemented")
 
     def solution(self, e, v, extra_constraints=(), exact=None):
@@ -149,6 +151,7 @@ class ConstrainedFrontend(Frontend):  # pylint:disable=abstract-method
     def is_false(self, e, extra_constraints=(), exact=None):
         raise NotImplementedError("is_false() is not implemented")
 
+
 from ..ast.base import simplify
 from ..ast.bool import And, Or
 from ..annotation import SimplificationAvoidanceAnnotation
